@@ -23,7 +23,6 @@ from hsfs.core import feature_group_base_engine, hudi_engine
 
 class FeatureGroupEngine(feature_group_base_engine.FeatureGroupBaseEngine):
     def save(self, feature_group, feature_dataframe, write_options):
-
         if len(feature_group.features) == 0:
             # User didn't provide a schema. extract it from the dataframe
             feature_group._features = engine.get_instance().parse_schema_feature_group(
@@ -45,10 +44,7 @@ class FeatureGroupEngine(feature_group_base_engine.FeatureGroupBaseEngine):
 
         self._feature_group_api.save(feature_group)
         validation_id = None
-        if (
-            feature_group.validation_type != "NONE"
-            and engine.get_instance().get_type() == "spark"
-        ):
+        if feature_group.validation_type != "NONE" and engine.get_type() == "spark":
             # If the engine is Hive, the validation will be executed by
             # the Hopsworks job ingesting the data
             validation = feature_group.validate(feature_dataframe)
@@ -80,10 +76,7 @@ class FeatureGroupEngine(feature_group_base_engine.FeatureGroupBaseEngine):
         write_options,
     ):
         validation_id = None
-        if (
-            feature_group.validation_type != "NONE"
-            and engine.get_instance().get_type() == "spark"
-        ):
+        if feature_group.validation_type != "NONE" and engine.get_type() == "spark":
             # If the engine is Hive, the validation will be executed by
             # the Hopsworks job ingesting the data
             validation = feature_group.validate(feature_dataframe)
@@ -154,15 +147,6 @@ class FeatureGroupEngine(feature_group_base_engine.FeatureGroupBaseEngine):
         )
         return hudi_engine_instance.delete_record(delete_df, write_options)
 
-    def update_validation_type(self, feature_group):
-        """Update the validation type specified of the feature group ."""
-        self._feature_group_api.update_metadata(
-            feature_group,
-            feature_group,
-            "validationType",
-            feature_group.validation_type,
-        )
-
     def sql(self, query, feature_store_name, dataframe_type, online, read_options):
         if online:
             online_conn = self._storage_connector_api.get_online_connector()
@@ -177,10 +161,10 @@ class FeatureGroupEngine(feature_group_base_engine.FeatureGroupBaseEngine):
         # perform changes on copy in case the update fails, so we don't leave
         # the user object in corrupted state
         copy_feature_group = fg.FeatureGroup(
-            name=None,
-            version=None,
-            featurestore_id=None,
-            description=None,
+            None,
+            None,
+            None,
+            None,
             id=feature_group.id,
             features=feature_group.features + new_features,
         )
@@ -191,10 +175,10 @@ class FeatureGroupEngine(feature_group_base_engine.FeatureGroupBaseEngine):
     def update_description(self, feature_group, description):
         """Updates the description of a feature group."""
         copy_feature_group = fg.FeatureGroup(
-            name=None,
-            version=None,
-            featurestore_id=None,
-            description=description,
+            None,
+            None,
+            description,
+            None,
             id=feature_group.id,
             features=feature_group.features,
         )
