@@ -14,10 +14,7 @@
 #   limitations under the License.
 #
 
-
-from datetime import datetime
-
-from hsfs import feature_group_commit, storage_connector, util
+from hsfs import feature_group_commit, util, client
 from hsfs.core import feature_group_api, storage_connector_api
 
 
@@ -42,6 +39,9 @@ class HudiEngine:
     DEFAULT_HIVE_PARTITION_EXTRACTOR_CLASS_OPT_VAL = (
         "org.apache.hudi.hive.MultiPartKeysValueExtractor"
     )
+    HIVE_NON_PARTITION_EXTRACTOR_CLASS_OPT_VAL = (
+        "org.apache.hudi.hive.NonPartitionedExtractor"
+    )
     HUDI_COPY_ON_WRITE = "COPY_ON_WRITE"
     HUDI_BULK_INSERT = "bulk_insert"
     HUDI_INSERT = "insert"
@@ -68,25 +68,40 @@ class HudiEngine:
         self._feature_store_id = feature_store_id
         self._feature_store_name = feature_store_name
         self._base_path = self._feature_group.location
-        self._table_name = feature_group.name + "_" + str(feature_group.version)
+        self._table_name = feature_group._get_online_table_name()
 
         self._primary_key = ",".join(feature_group.primary_key)
-        self._partition_key = ",".join(feature_group.partition_key)
-        self._partition_path = ":SIMPLE,".join(feature_group.partition_key) + ":SIMPLE"
-        self._pre_combine_key = feature_group.primary_key[0]
+        self._partition_key = (
+            ",".join(feature_group.partition_key)
+            if len(feature_group.partition_key) >= 1
+            else ""
+        )
+        self._partition_path = (
+            ":SIMPLE,".join(feature_group.partition_key) + ":SIMPLE"
+            if len(feature_group.partition_key) >= 1
+            else ""
+        )
+        self._pre_combine_key = (
+            feature_group.hudi_precombine_key
+            if feature_group.hudi_precombine_key
+            else feature_group.primary_key[0]
+        )
 
         self._feature_group_api = feature_group_api.FeatureGroupApi(feature_store_id)
         self._storage_connector_api = storage_connector_api.StorageConnectorApi(
             self._feature_store_id
         )
         self._connstr = self._storage_connector_api.get(
-            self._feature_store_name, storage_connector.StorageConnector.JDBC,
+            self._feature_store_name
         ).connection_string
 
-    def save_hudi_fg(self, dataset, save_mode, operation, write_options):
+    def save_hudi_fg(
+        self, dataset, save_mode, operation, write_options, validation_id=None
+    ):
         fg_commit = self._write_hudi_dataset(
             dataset, save_mode, operation, write_options
         )
+        fg_commit.validation_id = validation_id
         return self._feature_group_api.commit(self._feature_group, fg_commit)
 
     def delete_record(self, delete_df, write_options):
@@ -109,7 +124,6 @@ class HudiEngine:
 
     def _write_hudi_dataset(self, dataset, save_mode, operation, write_options):
         hudi_options = self._setup_hudi_write_opts(operation, write_options)
-
         dataset.write.format(HudiEngine.HUDI_SPARK_FORMAT).options(**hudi_options).mode(
             save_mode
         ).save(self._base_path)
@@ -124,11 +138,15 @@ class HudiEngine:
         _jdbc_url = self._get_conn_str()
         hudi_options = {
             self.HUDI_KEY_GENERATOR_OPT_KEY: self.HUDI_COMPLEX_KEY_GENERATOR_OPT_VAL,
-            self.HUDI_PRECOMBINE_FIELD: self._pre_combine_key,
+            self.HUDI_PRECOMBINE_FIELD: self._pre_combine_key[0]
+            if isinstance(self._pre_combine_key, list)
+            else self._pre_combine_key,
             self.HUDI_RECORD_KEY: self._primary_key,
             self.HUDI_PARTITION_FIELD: self._partition_path,
             self.HUDI_TABLE_NAME: self._table_name,
-            self.HIVE_PARTITION_EXTRACTOR_CLASS_OPT_KEY: self.DEFAULT_HIVE_PARTITION_EXTRACTOR_CLASS_OPT_VAL,
+            self.HIVE_PARTITION_EXTRACTOR_CLASS_OPT_KEY: self.DEFAULT_HIVE_PARTITION_EXTRACTOR_CLASS_OPT_VAL
+            if len(self._partition_key) >= 1
+            else self.HIVE_NON_PARTITION_EXTRACTOR_CLASS_OPT_VAL,
             self.HUDI_HIVE_SYNC_ENABLE: "true",
             self.HUDI_HIVE_SYNC_TABLE: self._table_name,
             self.HUDI_HIVE_SYNC_JDBC_URL: _jdbc_url,
@@ -143,8 +161,8 @@ class HudiEngine:
         return hudi_options
 
     def _setup_hudi_read_opts(self, start_timestamp, end_timestamp, read_options):
-        _hudi_commit_start_time = self._timestamp_to_hudiformat(start_timestamp)
-        _hudi_commit_end_time = self._timestamp_to_hudiformat(end_timestamp)
+        _hudi_commit_start_time = util.get_hudi_datestr_from_timestamp(start_timestamp)
+        _hudi_commit_end_time = util.get_hudi_datestr_from_timestamp(end_timestamp)
 
         hudi_options = {
             self.HUDI_QUERY_TYPE_OPT_KEY: self.HUDI_QUERY_TYPE_INCREMENTAL_OPT_VAL,
@@ -176,24 +194,22 @@ class HudiEngine:
         return feature_group_commit.FeatureGroupCommit(
             commitid=None,
             commit_date_string=commit_timeline.lastInstant().get().getTimestamp(),
+            commit_time=util.get_timestamp_from_date_string(
+                commit_timeline.lastInstant().get().getTimestamp()
+            ),
             rows_inserted=commit_metadata.fetchTotalInsertRecordsWritten(),
             rows_updated=commit_metadata.fetchTotalUpdateRecordsWritten(),
             rows_deleted=commit_metadata.getTotalRecordsDeleted(),
         )
 
-    @staticmethod
-    def _timestamp_to_hudiformat(timestamp):
-        date_obj = datetime.fromtimestamp(timestamp / 1000)
-        date_str = date_obj.strftime("%Y%m%d%H%M%S")
-        return date_str
-
     def _get_conn_str(self):
-        pw = util.get_cert_pw()
-        jdbc_url = (
-            self._connstr
-            + "sslTrustStore=t_certificate;trustStorePassword="
-            + pw
-            + ";sslKeyStore=k_certificate;keyStorePassword="
-            + pw
+        credentials = {
+            "sslTrustStore": client.get_instance()._get_jks_trust_store_path(),
+            "trustStorePassword": client.get_instance()._cert_key,
+            "sslKeyStore": client.get_instance()._get_jks_key_store_path(),
+            "keyStorePassword": client.get_instance()._cert_key,
+        }
+
+        return self._connstr + ";".join(
+            ["{}={}".format(option[0], option[1]) for option in credentials.items()]
         )
-        return jdbc_url
