@@ -15,7 +15,7 @@
 #
 
 from hsfs import client
-from hsfs.core import job
+from hsfs.core import job, execution
 
 
 class JobApi:
@@ -35,3 +35,16 @@ class JobApi:
         path_params = ["project", _client._project_id, "jobs", name, "executions"]
 
         _client._send_request("POST", path_params)
+
+    def last_execution(self, job):
+        _client = client.get_instance()
+        path_params = ["project", _client._project_id, "jobs", job.name, "executions"]
+
+        query_params = {"limit": 1, "sort_by": "submissiontime:desc"}
+
+        headers = {"content-type": "application/json"}
+        return execution.Execution.from_response_json(
+            _client._send_request(
+                "GET", path_params, headers=headers, query_params=query_params
+            )
+        )
