@@ -19,6 +19,7 @@ import numpy as np
 import boto3
 import time
 
+from io import BytesIO
 from pyhive import hive
 from urllib.parse import urlparse
 
@@ -63,15 +64,15 @@ class Engine:
             result_df = pd.read_sql(sql_query, mysql_conn)
         return self._return_dataframe_type(result_df, dataframe_type)
 
-    def read(self, storage_connector, data_format, read_options, location, split=None):
-        if storage_connector.connector_type == storage_connector.HOPSFS:
-            df_list = self._read_hopsfs(location, split, data_format)
-        elif storage_connector.connector_type == storage_connector.S3:
-            df_list = self._read_s3(storage_connector, location, split, data_format)
+    def read(self, storage_connector, data_format, read_options, location):
+        if storage_connector.type == storage_connector.HOPSFS:
+            df_list = self._read_hopsfs(location, data_format)
+        elif storage_connector.type == storage_connector.S3:
+            df_list = self._read_s3(storage_connector, location, data_format)
         else:
             raise NotImplementedError(
                 "{} Storage Connectors for training datasets are not supported yet for external environments.".format(
-                    storage_connector.connector_type
+                    storage_connector.type
                 )
             )
         return pd.concat(df_list, ignore_index=True)
@@ -82,7 +83,7 @@ class Engine:
         elif data_format.lower() == "tsv":
             return pd.read_csv(obj, sep="\t")
         elif data_format.lower() == "parquet":
-            return pd.read_parquet(obj)
+            return pd.read_parquet(BytesIO(obj.read()))
         else:
             raise TypeError(
                 "{} training dataset format is not supported to read as pandas dataframe. If you are using `tfrecord` use the `.tf_data` helper functions.".format(
@@ -90,7 +91,7 @@ class Engine:
                 )
             )
 
-    def _read_hopsfs(self, location, split, data_format):
+    def _read_hopsfs(self, location, data_format):
         # providing more informative error
         try:
             from pydoop import hdfs
@@ -100,11 +101,7 @@ class Engine:
             ) from err
 
         util.setup_pydoop()
-
-        if split is None:
-            path_list = hdfs.ls(location, recursive=True)
-        else:
-            path_list = hdfs.ls(location + "/" + str(split), recursive=True)
+        path_list = hdfs.ls(location, recursive=True)
 
         df_list = []
         for path in path_list:
@@ -116,14 +113,11 @@ class Engine:
                 df_list.append(self._read_pandas(data_format, path))
         return df_list
 
-    def _read_s3(self, storage_connector, location, split, data_format):
+    def _read_s3(self, storage_connector, location, data_format):
         # get key prefix
         path_parts = location.replace("s3://", "").split("/")
         _ = path_parts.pop(0)  # pop first element -> bucket
 
-        if split is not None and isinstance(split, str):
-            path_parts.append(split)
-
         prefix = "/".join(path_parts)
 
         if storage_connector.session_token is not None:
@@ -172,7 +166,7 @@ class Engine:
     def show(self, sql_query, feature_store, n, online_conn):
         return self.sql(sql_query, feature_store, online_conn, "default", {}).head(n)
 
-    def register_on_demand_temporary_table(self, query, storage_connector, alias):
+    def register_on_demand_temporary_table(self, on_demand_fg, alias):
         raise NotImplementedError
 
     def register_hudi_temporary_table(
