@@ -24,12 +24,13 @@ import numpy as np
 
 from hsfs import util, engine, training_dataset_feature
 from hsfs.statistics_config import StatisticsConfig
-from hsfs.storage_connector import StorageConnector
+from hsfs.storage_connector import StorageConnector, HopsFSConnector
 from hsfs.core import (
     training_dataset_api,
     training_dataset_engine,
     tfdata_engine,
     statistics_engine,
+    transformation_function_engine,
 )
 from hsfs.constructor import query
 
@@ -62,6 +63,7 @@ class TrainingDataset:
         from_query=None,
         querydto=None,
         label=None,
+        transformation_functions=None,
     ):
         self._id = id
         self._name = name
@@ -77,6 +79,7 @@ class TrainingDataset:
         self._prepared_statement_connection = None
         self._prepared_statements = None
         self._serving_keys = None
+        self._transformation_functions = transformation_functions
 
         self._training_dataset_api = training_dataset_api.TrainingDatasetApi(
             featurestore_id
@@ -90,6 +93,10 @@ class TrainingDataset:
             featurestore_id, self.ENTITY_TYPE
         )
 
+        self._transformation_function_engine = (
+            transformation_function_engine.TransformationFunctionEngine(featurestore_id)
+        )
+
         # set up depending on user initialized or coming from backend response
         if training_dataset_type is None:
             # no type -> user init
@@ -497,8 +504,8 @@ class TrainingDataset:
             self._storage_connector = storage_connector
         elif storage_connector is None:
             # init empty connector, otherwise will have to handle it at serialization time
-            self._storage_connector = StorageConnector(
-                None, None, None, None, None, None, None, None
+            self._storage_connector = HopsFSConnector(
+                None, None, None, None, None, None
             )
         else:
             raise TypeError(
@@ -507,7 +514,7 @@ class TrainingDataset:
                 )
             )
         self._training_dataset_type = self._infer_training_dataset_type(
-            self._storage_connector.connector_type
+            self._storage_connector.type
         )
 
     @property
@@ -686,3 +693,16 @@ class TrainingDataset:
     @serving_keys.setter
     def serving_keys(self, serving_vector_keys):
         self._serving_keys = serving_vector_keys
+
+    @property
+    def transformation_functions(self):
+        """Set transformation functions."""
+        if self._id is not None and self._transformation_functions is None:
+            self._transformation_functions = (
+                self._transformation_function_engine.get_td_transformation_fn(self)
+            )
+        return self._transformation_functions
+
+    @transformation_functions.setter
+    def transformation_functions(self, transformation_functions):
+        self._transformation_functions = transformation_functions
